@@ -19,7 +19,8 @@ class CircularDrawer(Drawer):
     def __init__(self, p):
         super().__init__(p)
 
-    def draw(self, dr, size):
+    def draw(self, dr, size, is_summary=False):
+        # TODO: make a summary circle
         if self.poster.tracks is None:
             raise CircularDrawError("No tracks to draw.")
         if self.poster.length_range_by_date is None:
@@ -42,10 +43,8 @@ class CircularDrawer(Drawer):
         center = offset + 0.5 * size
 
         year_style = f"dominant-baseline: central; font-size:{min_size * 4.0 / 80.0}px; \
-                       font-family:{self.poster.font};"
-        month_style = (
-            f"font-size:{min_size * 3.0 / 80.0}px; font-family:{self.poster.font};"
-        )
+                       font-family:Arial;"
+        month_style = f"font-size:{min_size * 3.0 / 80.0}px; font-family:Arial;"
 
         year_text = dr.text(
             f"{year}",
