@@ -17,6 +17,7 @@ from github_poster.loader.nrc_loader import NRCLoader
 from github_poster.loader.ns_loader import NSLoader
 from github_poster.loader.shanbay_loader import ShanBayLoader
 from github_poster.loader.strava_loader import StravaLoader
+from github_poster.loader.summary_loader import SummaryLoader
 from github_poster.loader.twitter_loader import TwitterLoader
 from github_poster.loader.wakatime_loader import WakaTimeLoader
 from github_poster.loader.youtube_loader import YouTubeLoader
@@ -44,6 +45,7 @@ LOADER_DICT = {
     "forest": ForestLoader,
     "json": JsonLoader,
     "jike": JikeLoader,
+    "summary": SummaryLoader,
 }
 
 __all__ = (
@@ -70,4 +72,5 @@ __all__ = (
     "GarminLoader",
     "JsonLoader",
     "JikeLoader",
+    "SummaryLoader",
 )
