@@ -13,12 +13,12 @@ class TwitterLoader(BaseLoader):
         self.c = twint.Config()
 
     @classmethod
-    def add_loader_arguments(cls, parser):
+    def add_loader_arguments(cls, parser, optional):
         parser.add_argument(
             "--twitter_user_name",
             dest="twitter_user_name",
             type=str,
-            required=True,
+            required=optional,
             help="",
         )
 
